@@ -5,7 +5,6 @@ import (
 
 	"github.com/cli/cli/v2/pkg/cmd/attestation/io"
 	"github.com/cli/cli/v2/pkg/cmd/attestation/test/data"
-
 	"github.com/stretchr/testify/require"
 )
 
@@ -17,7 +16,8 @@ const (
 
 func NewClientWithMockGHClient(hasNextPage bool) Client {
 	fetcher := mockDataGenerator{
-		NumAttestations: 5,
+		NumUserAttestations:   5,
+		NumGitHubAttestations: 4,
 	}
 	l := io.NewTestHandler()
 
@@ -42,83 +42,94 @@ func NewClientWithMockGHClient(hasNextPage bool) Client {
 	}
 }
 
+var testFetchParamsWithOwner = FetchParams{
+	Digest:        testDigest,
+	Limit:         DefaultLimit,
+	Owner:         testOwner,
+	PredicateType: "https://slsa.dev/provenance/v1",
+	Initiator:     "user",
+}
+var testFetchParamsWithRepo = FetchParams{
+	Digest:        testDigest,
+	Limit:         DefaultLimit,
+	Repo:          testRepo,
+	PredicateType: "https://slsa.dev/provenance/v1",
+	Initiator:     "user",
+}
+
+var testFetchParamsWithRepoWithGitHubInitiator = FetchParams{
+	Digest:    testDigest,
+	Limit:     DefaultLimit,
+	Repo:      testRepo,
+	Initiator: "github",
+}
+
+type getByTestCase struct {
+	name                 string
+	params               FetchParams
+	limit                int
+	expectedAttestations int
+	hasNextPage          bool
+}
+
+var getByTestCases = []getByTestCase{
+	{
+		name:                 "get by digest with owner",
+		params:               testFetchParamsWithOwner,
+		expectedAttestations: 5,
+	},
+	{
+		name:                 "get by digest with repo",
+		params:               testFetchParamsWithRepo,
+		expectedAttestations: 5,
+	},
+	{
+		name:                 "get by digest with attestations greater than limit",
+		params:               testFetchParamsWithRepo,
+		limit:                3,
+		expectedAttestations: 3,
+	},
+	{
+		name:                 "get by digest with next page",
+		params:               testFetchParamsWithRepo,
+		expectedAttestations: 10,
+		hasNextPage:          true,
+	},
+	{
+		name:                 "greater than limit with next page",
+		params:               testFetchParamsWithRepo,
+		limit:                7,
+		expectedAttestations: 7,
+		hasNextPage:          true,
+	},
+	{
+		name:                 "get by digest with repo and GitHub initiator",
+		params:               testFetchParamsWithRepoWithGitHubInitiator,
+		expectedAttestations: 4,
+	},
+}
+
 func TestGetByDigest(t *testing.T) {
-	c := NewClientWithMockGHClient(false)
-	attestations, err := c.GetByRepoAndDigest(testRepo, testDigest, DefaultLimit)
-	require.NoError(t, err)
+	for _, tc := range getByTestCases {
+		t.Run(tc.name, func(t *testing.T) {
+			c := NewClientWithMockGHClient(tc.hasNextPage)
 
-	require.Equal(t, 5, len(attestations))
-	bundle := (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
+			if tc.limit > 0 {
+				tc.params.Limit = tc.limit
+			}
+			attestations, err := c.GetByDigest(tc.params)
+			require.NoError(t, err)
 
-	attestations, err = c.GetByOwnerAndDigest(testOwner, testDigest, DefaultLimit)
-	require.NoError(t, err)
-
-	require.Equal(t, 5, len(attestations))
-	bundle = (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
-}
-
-func TestGetByDigestGreaterThanLimit(t *testing.T) {
-	c := NewClientWithMockGHClient(false)
-
-	limit := 3
-	// The method should return five results when the limit is not set
-	attestations, err := c.GetByRepoAndDigest(testRepo, testDigest, limit)
-	require.NoError(t, err)
-
-	require.Equal(t, 3, len(attestations))
-	bundle := (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
-
-	attestations, err = c.GetByOwnerAndDigest(testOwner, testDigest, limit)
-	require.NoError(t, err)
-
-	require.Equal(t, len(attestations), limit)
-	bundle = (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
-}
-
-func TestGetByDigestWithNextPage(t *testing.T) {
-	c := NewClientWithMockGHClient(true)
-	attestations, err := c.GetByRepoAndDigest(testRepo, testDigest, DefaultLimit)
-	require.NoError(t, err)
-
-	require.Equal(t, len(attestations), 10)
-	bundle := (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
-
-	attestations, err = c.GetByOwnerAndDigest(testOwner, testDigest, DefaultLimit)
-	require.NoError(t, err)
-
-	require.Equal(t, len(attestations), 10)
-	bundle = (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
-}
-
-func TestGetByDigestGreaterThanLimitWithNextPage(t *testing.T) {
-	c := NewClientWithMockGHClient(true)
-
-	limit := 7
-	// The method should return five results when the limit is not set
-	attestations, err := c.GetByRepoAndDigest(testRepo, testDigest, limit)
-	require.NoError(t, err)
-
-	require.Equal(t, len(attestations), limit)
-	bundle := (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
-
-	attestations, err = c.GetByOwnerAndDigest(testOwner, testDigest, limit)
-	require.NoError(t, err)
-
-	require.Equal(t, len(attestations), limit)
-	bundle = (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
+			require.Equal(t, tc.expectedAttestations, len(attestations))
+			bundle := (attestations)[0].Bundle
+			require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
+		})
+	}
 }
 
 func TestGetByDigest_NoAttestationsFound(t *testing.T) {
 	fetcher := mockDataGenerator{
-		NumAttestations: 5,
+		NumUserAttestations: 5,
 	}
 
 	httpClient := &mockHttpClient{}
@@ -130,12 +141,7 @@ func TestGetByDigest_NoAttestationsFound(t *testing.T) {
 		logger:     io.NewTestHandler(),
 	}
 
-	attestations, err := c.GetByRepoAndDigest(testRepo, testDigest, DefaultLimit)
-	require.Error(t, err)
-	require.IsType(t, ErrNoAttestationsFound, err)
-	require.Nil(t, attestations)
-
-	attestations, err = c.GetByOwnerAndDigest(testOwner, testDigest, DefaultLimit)
+	attestations, err := c.GetByDigest(testFetchParamsWithRepo)
 	require.Error(t, err)
 	require.IsType(t, ErrNoAttestationsFound, err)
 	require.Nil(t, attestations)
@@ -143,7 +149,7 @@ func TestGetByDigest_NoAttestationsFound(t *testing.T) {
 
 func TestGetByDigest_Error(t *testing.T) {
 	fetcher := mockDataGenerator{
-		NumAttestations: 5,
+		NumUserAttestations: 5,
 	}
 
 	c := LiveClient{
@@ -153,11 +159,7 @@ func TestGetByDigest_Error(t *testing.T) {
 		logger: io.NewTestHandler(),
 	}
 
-	attestations, err := c.GetByRepoAndDigest(testRepo, testDigest, DefaultLimit)
-	require.Error(t, err)
-	require.Nil(t, attestations)
-
-	attestations, err = c.GetByOwnerAndDigest(testOwner, testDigest, DefaultLimit)
+	attestations, err := c.GetByDigest(testFetchParamsWithRepo)
 	require.Error(t, err)
 	require.Nil(t, attestations)
 }
@@ -351,7 +353,7 @@ func TestGetAttestationsRetries(t *testing.T) {
 	getAttestationRetryInterval = 0
 
 	fetcher := mockDataGenerator{
-		NumAttestations: 5,
+		NumUserAttestations: 5,
 	}
 
 	c := &LiveClient{
@@ -362,7 +364,8 @@ func TestGetAttestationsRetries(t *testing.T) {
 		logger:     io.NewTestHandler(),
 	}
 
-	attestations, err := c.GetByRepoAndDigest(testRepo, testDigest, DefaultLimit)
+	testFetchParamsWithRepo.Limit = 30
+	attestations, err := c.GetByDigest(testFetchParamsWithRepo)
 	require.NoError(t, err)
 
 	// assert the error path was executed; because this is a paged
@@ -373,17 +376,6 @@ func TestGetAttestationsRetries(t *testing.T) {
 	require.Equal(t, len(attestations), 10)
 	bundle := (attestations)[0].Bundle
 	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
-
-	// same test as above, but for GetByOwnerAndDigest:
-	attestations, err = c.GetByOwnerAndDigest(testOwner, testDigest, DefaultLimit)
-	require.NoError(t, err)
-
-	// because we haven't reset the mock, we have added 2 more failed requests
-	fetcher.AssertNumberOfCalls(t, "FlakyOnRESTSuccessWithNextPage:error", 4)
-
-	require.Equal(t, len(attestations), 10)
-	bundle = (attestations)[0].Bundle
-	require.Equal(t, bundle.GetMediaType(), "application/vnd.dev.sigstore.bundle.v0.3+json")
 }
 
 // test total retries
@@ -391,7 +383,7 @@ func TestGetAttestationsMaxRetries(t *testing.T) {
 	getAttestationRetryInterval = 0
 
 	fetcher := mockDataGenerator{
-		NumAttestations: 5,
+		NumUserAttestations: 5,
 	}
 
 	c := &LiveClient{
@@ -401,7 +393,7 @@ func TestGetAttestationsMaxRetries(t *testing.T) {
 		logger: io.NewTestHandler(),
 	}
 
-	_, err := c.GetByRepoAndDigest(testRepo, testDigest, DefaultLimit)
+	_, err := c.GetByDigest(testFetchParamsWithRepo)
 	require.Error(t, err)
 
 	fetcher.AssertNumberOfCalls(t, "OnREST500Error", 4)
